收集电报群组的视频图片消息

快速开始
```shell
pip install telegram_collector
tgc -c #创建默认配置文件
vim tg.ini #修改配置
tgc -b #开启收集
```

使用手册
```shell
> tgc
-a: collect new messages
-b: collect history messages
-c: create an example config
-p: print dialogs information

```
